@@ -1,13 +1,19 @@
 import sys
 import httplib
-import simplejson
+try:
+    import json as simplejson # For Python 2.6
+except ImportError:
+    import simplejson
 from urlparse import urlparse, urlunparse
-from cgi import parse_qs # 2.5 compat
+try:
+    from urlparse import parse_qs
+except ImportError:
+    from cgi import parse_qs
 from urllib import urlencode
 
-GITHUB_URL = "http://github.com"
+GITHUB_URL = "https://github.com"
 
-URL_PREFIX = "http://github.com/api/v2/json"
+URL_PREFIX = "https://github.com/api/v2/json"
 
 class GithubError(Exception):
     """An error occured when making a request to the Github API."""
@@ -24,7 +30,7 @@ class GithubRequest(object):
         "https": httplib.HTTPSConnection,
     }
 
-    def __init__(self, username, api_token, url_prefix=None, debug=False):
+    def __init__(self, username=None, api_token=None, url_prefix=None, debug=False):
         self.username = username
         self.api_token = api_token
         self.url_prefix = url_prefix
@@ -37,8 +43,11 @@ class GithubRequest(object):
             }
 
     def encode_authentication_data(self, extra_post_data):
-        post_data = {"login": self.username,
-                     "token": self.api_token}
+        if self.username and self.api_token:
+            post_data = {"login": self.username,
+                         "token": self.api_token}
+        else:
+            post_data = {}
         post_data.update(extra_post_data) 
         return urlencode(post_data)
 
